@@ -4,8 +4,9 @@
 use simple_logger::SimpleLogger;
 use tao::{
   dpi::LogicalSize,
-  event::{ElementState, Event, KeyboardInput, VirtualKeyCode, WindowEvent},
+  event::{ElementState, Event, KeyEvent, WindowEvent},
   event_loop::{ControlFlow, EventLoop},
+  keyboard::KeyCode,
   window::WindowBuilder,
 };
 
@@ -30,9 +31,9 @@ fn main() {
       Event::WindowEvent { event, .. } => match event {
         WindowEvent::CloseRequested => *control_flow = ControlFlow::Exit,
         WindowEvent::KeyboardInput {
-          input:
-            KeyboardInput {
-              virtual_keycode: Some(VirtualKeyCode::Space),
+          event:
+            KeyEvent {
+              physical_key: KeyCode::Space,
               state: ElementState::Released,
               ..
             },
