@@ -168,7 +168,7 @@ impl Menu {
         make_menu_item(
           "Close Window",
           Some(selector("performClose:")),
-          Some(Accelerator::new(RawMods::Meta, KeyCode::KeyX)),
+          Some(Accelerator::new(RawMods::Meta, KeyCode::KeyW)),
           menu_type,
         ),
       )),
@@ -271,7 +271,7 @@ impl Menu {
         make_menu_item(
           "Redo",
           Some(selector("redo:")),
-          Some(Accelerator::new(RawMods::Shift, KeyCode::KeyZ)),
+          Some(Accelerator::new(RawMods::MetaShift, KeyCode::KeyZ)),
           menu_type,
         ),
       )),
@@ -378,10 +378,11 @@ fn make_menu_item_from_alloc(
     // allocate our item to our class
     let item: id =
       msg_send![alloc, initWithTitle: title action: selector keyEquivalent: key_equivalent];
-    if let Some(masks) = accelerator.map(Accelerator::key_modifier_mask) {
-      item.setKeyEquivalentModifierMask_(masks)
-    }
 
+    let mask = accelerator
+      .map(Accelerator::key_modifier_mask)
+      .unwrap_or_else(NSEventModifierFlags::empty);
+    item.setKeyEquivalentModifierMask_(mask);
     item
   }
 }
@@ -468,6 +469,8 @@ impl Accelerator {
   /// Returns the empty string if no key equivalent is known.
   fn key_equivalent(self) -> String {
     match self.key {
+      KeyCode::Minus => "-".into(),
+      KeyCode::Equal => "=".into(),
       KeyCode::KeyA => "a".into(),
       KeyCode::KeyB => "b".into(),
       KeyCode::KeyC => "c".into(),
@@ -504,6 +507,8 @@ impl Accelerator {
       KeyCode::Digit7 => "7".into(),
       KeyCode::Digit8 => "8".into(),
       KeyCode::Digit9 => "9".into(),
+      KeyCode::Escape => "\u{1b}".into(),
+      KeyCode::Space => "\u{0020}".into(),
       // from NSText.h
       KeyCode::Enter => "\u{0003}".into(),
       KeyCode::Backspace => "\u{0008}".into(),
