@@ -19,7 +19,8 @@ use objc::{
 
 use crate::{
   dpi::{LogicalPosition, LogicalSize},
-  event::{Event, ModifiersState, WindowEvent},
+  event::{Event, WindowEvent},
+  keyboard::ModifiersState,
   platform_impl::platform::{
     app_state::{AppState, INTERRUPT_EVENT_LOOP_EXIT},
     event::{EventProxy, EventWrapper},
@@ -56,7 +57,7 @@ impl WindowDelegateState {
     let mut delegate_state = WindowDelegateState {
       ns_window: window.ns_window.clone(),
       ns_view: window.ns_view.clone(),
-      window: Arc::downgrade(&window),
+      window: Arc::downgrade(window),
       initial_fullscreen,
       previous_position: None,
       previous_scale_factor: scale_factor,
